==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 플러그인이 시스템과 호환되지 않습니다.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>블루투스 설정</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>끄기</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>켜기</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>블루투스 설정</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 연결됨</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>연결하는 중...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>블루투스</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>꺼짐</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>블루투스</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>키보드 레이아웃 추가</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>날짜시간</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 시간</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24시간</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>시간 설정</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>네트워크 사용</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>네트워크 사용안함</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>네트워크 설정</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 항목을 비우시겠습니까?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>이 동작은 되돌릴 수 없습니다</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>알 수 없는 장치</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>알 수 없는 볼륨</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>디스크</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>모두 마운트 해제</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>실행도구</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>시각 모드</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>효율 모드</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>상단</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>하단</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>왼쪽</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>오른쪽</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>표시된 상태로 유지</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>숨겨진 상태로 유지</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>스마트 숨기기</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>플러그인</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>멀티태스킹 보기</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>도구집 해제</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>유선 연결 사용안함</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>유선 연결 사용가능</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>무선 연결 사용안함</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>무선 연결 사용가능</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>네트워크 사용안함</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>네트워크 사용</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>네트워크 설정</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>디바이스 사용해제됨</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>무선 연결: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>유선 연결: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>연결되지 않음</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>연결 중</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>연결됨, 인터넷 없음</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>네트워크 케이블 제거됨</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>유선 네트워크 %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>온보드</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정 </translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>전원</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>전원 설정</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>용량 %1, %2분 남음</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>용량 %1, %2시간 %3분 남음</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 충전중, 완전 충전까지 %2분 남음</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 충전중, 완전 충전까지 %2시간 %3분 남음</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>충전됨</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>용량 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 충전중</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>용량 %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>용량 %1, 완전히 충전됨</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>바탕화면 표시</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>도구집 해제</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>전원</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>대기모드</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>최대 절전 모드</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠금</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>계정 전환</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>전원 설정</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>재부팅</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>장치</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>음소거 해제</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>음소거</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>사운드 설정</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>음량 %1%</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>사운드</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>휴지통</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>휴지통 - %1 파일</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>휴지통 - %1 파일</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>비우기</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>시스템 트레이</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>무선 네트워크 %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 플러그인이 시스템과 호환되지 않습니다.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>비행기 모드</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>끄기</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>켜기</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>비행기 모드 설정</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>비행기 모드</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>블루투스 설정</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>끄기</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>켜기</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>블루투스 설정</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 연결됨</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>연결하는 중...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>블루투스</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>꺼짐</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>블루투스</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>키보드 레이아웃 추가</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>날짜시간</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 시간</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24시간</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>시간 설정</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>월요일</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>화요일</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>수요일</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>목요일</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>금요일</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>토요일</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>일요일</translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 항목을 비우시겠습니까?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>이 동작은 되돌릴 수 없습니다</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>알 수 없는 장치</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>알 수 없는 볼륨</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>디스크</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>모두 마운트 해제</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>실행도구</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>시각 모드</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>효율 모드</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>상단</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>하단</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>왼쪽</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>오른쪽</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>표시된 상태로 유지</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>숨겨진 상태로 유지</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>스마트 숨기기</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>크기</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>다중 디스플레이</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>패션(Fashion) 모드</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>효율 모드</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>상단</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>하단</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>왼쪽</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>오른쪽</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>위치</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>숨겨두기</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>스마트하이드</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>소형</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>대형</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>멀티태스킹 보기</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>도구집 해제</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>온보드</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정 </translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>전원</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>전원 설정</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>용량 %1, %2분 남음</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>용량 %1, %2시간 %3분 남음</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 충전중, 완전 충전까지 %2분 남음</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 충전중, 완전 충전까지 %2시간 %3분 남음</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>용량 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 충전중</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>용량 %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>용량 %1, 완전히 충전됨</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>도구집</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>바탕화면 표시</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>도구집 해제</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>전원</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>대기모드</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>최대 절전 모드</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠금</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>계정 전환</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>전원 설정</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>재부팅</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>음량</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>음소거 해제</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>음소거</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>사운드 설정</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>음량 %1%</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>사운드</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>휴지통</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>휴지통 - %1 파일</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>휴지통 - %1 파일</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>휴지통으로 이동</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>비우기</translation>
    </message>
</context>
</TS>
